@@ -10,7 +10,7 @@ from collections import namedtuple
 from importlib.metadata import version
 from os import environ
 from pathlib import Path
-from typing import List, Optional, Union
+from typing import List, Union
 
 from rich import box
 from rich.console import Console
@@ -37,10 +37,12 @@ class Config:
     debug: bool = False
     dry_run: bool = True
     manual_sort: bool = False
+    only_if_match: bool = False
     leave_in_place: bool = False
     screenshots_only: bool = True
     delete_originals: bool = False
     rescan_sorted: bool = False
+    yes_overwrite: bool = False
     sort_rules: List[SortRule] = []
     filename_regex: re.Pattern
 
@@ -66,8 +68,10 @@ class Config:
         Config.set_directories(screenshots_dir, destination_dir, rules_csvs)
         Config.filename_regex = re.compile(args.filename_regex)
         Config.leave_in_place = True if args.leave_in_place else False
+        Config.only_if_match = True if args.only_if_match else False
         Config.delete_originals = True if args.delete_originals else False
         Config.rescan_sorted = True if args.rescan_sorted else False
+        Config.yes_overwrite = True if args.yes_overwrite else False
 
         if Config.leave_in_place and Config.delete_originals:
             Console().print("--leave-in-place and --delete-originals are mutually exclusive.", style='red')
