@@ -7,17 +7,17 @@ Tags: https://exiftool.org/TagNames/EXIF.html
 """
 import io
 from pathlib import Path
-from typing import Optional, Union
+from typing import Optional
 
 import pytesseract
 from PIL import Image
 from PIL.ExifTags import TAGS
 
 from clown_sort.config import Config
-from clown_sort.util.logging import log
 from clown_sort.filename_extractor import FilenameExtractor
 from clown_sort.files.sortable_file import SortableFile
 from clown_sort.util.filesystem_helper import copy_file_creation_time
+from clown_sort.util.logging import log
 from clown_sort.util.rich_helper import console
 
 THUMBNAIL_DIMENSIONS = (400, 400)
